#
# spec file for package osmo-bts
#
# Copyright (c) 2021 SUSE LLC
# Copyright (c) 2017-2021, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           osmo-bts
Version:        1.4.0
Release:        bp156.2.9
Summary:        Osmocom BTS-Side code (Abis, scheduling)
License:        AGPL-3.0-or-later AND GPL-2.0-only
Group:          Productivity/Telephony/Servers
URL:            https://osmocom.org/projects/osmobts/wiki/Wiki
Source:         %{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  pkgconfig >= 0.20
BuildRequires:  systemd-rpm-macros
BuildRequires:  pkgconfig(libosmoabis) >= 1.2.0
BuildRequires:  pkgconfig(libosmocodec) >= 1.6.0
BuildRequires:  pkgconfig(libosmocoding) >= 1.6.0
BuildRequires:  pkgconfig(libosmocore) >= 1.6.0
BuildRequires:  pkgconfig(libosmoctrl) >= 1.6.0
BuildRequires:  pkgconfig(libosmogb)
BuildRequires:  pkgconfig(libosmogsm) >= 1.6.0
BuildRequires:  pkgconfig(libosmotrau) >= 1.2.0
BuildRequires:  pkgconfig(libosmovty) >= 1.6.0

%description
Osmocom BTS-Side code (A-bis, scheduling).

%package -n osmo-bts-virtual
Summary:        Virtual Osmocom GSM BTS (no RF hardware; GSMTAP/UDP)
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities

%description -n osmo-bts-virtual
This version of OsmoBTS doesn't use actual GSM PHY/Hardware/RF, but
utilizes GSMTAP-over-UDP frames for the Um interface.  This is useful
in fully virtualized setups e.g. in combination with OsmocomBB virt_phy.

%package -n osmo-bts-omldummy
Summary:        Osmocom CI: Bring up only OML without RSL
License:        GPL-2.0-or-later
Group:          Productivity/Telephony/Utilities

%description -n osmo-bts-omldummy
This is used only in integration testing, where in the TTCN-3 testsuite
we currently have no A-bis OML implementation, but only a RSL one.

%prep
%setup -q

%build
echo "%{version}" >.tarball-version
autoreconf -fi
%configure \
    --docdir="%{_docdir}/%{name}" \
    --with-systemdsystemunitdir=%{_unitdir} \
    --enable-trx
make V=1 %{?_smp_mflags}

%install
%make_install
install -d %{buildroot}/%{_sbindir}
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcosmo-bts-trx
ln -s %{_sbindir}/service %{buildroot}/%{_sbindir}/rcosmo-bts-virtual

%pre
%service_add_pre osmo-bts-trx.service

%post
%service_add_post osmo-bts-trx.service

%preun
%service_del_preun osmo-bts-trx.service

%postun
%service_del_postun osmo-bts-trx.service

%pre virtual
%service_add_pre osmo-bts-virtual.service

%post virtual
%service_add_post  osmo-bts-virtual.service

%preun virtual
%service_del_preun osmo-bts-virtual.service

%postun virtual
%service_del_postun osmo-bts-virtual.service

%check
make %{?_smp_mflags} check || (find . -name testsuite.log -exec cat {} +)

%files
%license COPYING
%doc README.md
%dir %{_docdir}/%{name}
%dir %{_docdir}/%{name}/examples
%dir %{_docdir}/%{name}/examples/osmo-bts-trx
%{_docdir}/%{name}/examples/osmo-bts-trx/osmo-bts-trx-calypso.cfg
%{_docdir}/%{name}/examples/osmo-bts-trx/osmo-bts-trx.cfg
%dir %{_docdir}/%{name}/examples/osmo-bts-virtual
%{_docdir}/%{name}/examples/osmo-bts-virtual/osmo-bts-virtual.cfg
%{_bindir}/osmo-bts-trx
%{_sbindir}/rcosmo-bts-trx
%dir %{_sysconfdir}/osmocom
%config(noreplace) %{_sysconfdir}/osmocom/osmo-bts-trx.cfg
%{_unitdir}/osmo-bts-trx.service

%files -n osmo-bts-virtual
%{_bindir}/osmo-bts-virtual
%{_sbindir}/rcosmo-bts-virtual
%dir %{_sysconfdir}/osmocom
%config(noreplace) %{_sysconfdir}/osmocom/osmo-bts-virtual.cfg
%{_unitdir}/osmo-bts-virtual.service

%files -n osmo-bts-omldummy
%{_bindir}/osmo-bts-omldummy

%changelog
* Fri Nov 19 2021 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.4.0
  * https://git.osmocom.org/osmo-bts/plain/debian/changelog?h=1.4.0
- Drop patch:
  * 0001-fix-compilation-with-gcc-10.patch
* Thu Jun 11 2020 Martin Hauke <mardnh@gmx.de>
- Add patch to fix gcc10 compilation errors (boo#1160244)
  * 0001-fix-compilation-with-gcc-10.patch
* Sun Jan  5 2020 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.2.0
  * Introduce BTS feature BTS_FEAT_MS_PWR_CTRL_DSP
  * Rename variable: CALIB_SUCESS -> CALIB_SUCCESS
  * ETWS Primary Notification via P1 Rest Octets
- Update to new upstream release 1.1.0
  * bts-trx: Introduce VTY command osmotrx trxd-max-version
  * bts-trx: trx_if.c: Introduce logging macro LOGPPHI
  * rsl: Implement parsing of BS Power Control message
  * cbch: Support Extended CBCH
  * Enable statsd support
* Sun Mar 31 2019 Martin Hauke <mardnh@gmx.de>
- Actually do the version bump to version 1.0.1
  * spec and tarball wasn't updated in the last SR (only the
    .changes file
* Wed Mar 27 2019 Martin Hauke <mardnh@gmx.de>
- Update to new upstream release 1.0.1
  * rsl.c: Add missing #include of gsm0808.h
* Tue Jan 29 2019 mardnh@gmx.de
- Update to new upstream release 1.0.0
  * various correctness fixes related to advanced SACCH FILL
    scenarios with different SI5/SI6 per channel/subscriber
  * various fixes to bit-rotten CBCH support; related generalization
  * CBCH support for osmo-bts-trx
  * extend precision of TOA mesaurement reports to 1/256 symbol duration
  * make RTP port range configurable
  * extensive fixes on correctness of computed + reported
    measurement reports
  * Fix build against gpsd >= 3.18
  * Allocate TRX for BTS dynamically, deprecate "-t" command line option
  * Initial support for OpenCellular OC-2G BTS model/PHY
  * Full changelogs since 0.7.0:
    http://git.osmocom.org/osmo-bts/plain/debian/changelog?h=1.0.0
    http://git.osmocom.org/osmo-bts/plain/debian/changelog?h=0.8.1
    http://git.osmocom.org/osmo-bts/plain/debian/changelog?h=0.8.0
- Remove not longer needed patches:
  * osmo-bts-fix-cflags.patch
  * 0001-l1sap-fix-wrong-return-value-of-is_fill_frame.patch
* Sat Mar 17 2018 mardnh@gmx.de
- Show testsuite.log when tests are failing
* Mon Jan  1 2018 jengelh@inai.de
- Remove unnecessary sysvinit script macros.
* Fri Dec 29 2017 mardnh@gmx.de
- Remove handcrafted CFLAGS
- Add patch:
  * 0001-l1sap-fix-wrong-return-value-of-is_fill_frame.patch
* Wed Dec 27 2017 mardnh@gmx.de
- Update to new upstream release 0.7.0
  * No changelog was provided
- Specfile cleanup
- Add patch
  * osmo-bts-fix-cflags.patch
* Wed Feb 15 2017 mardnh@gmx.de
- Update to version 0.4.0.git1487093487.6b4c6aa:
  * Log socket path on error
  * Add Abis OML failure event reporting
  * Alarm on various errors
  * RSL: drop obsolete NULL check
  * RSL: add assertions to check args of public API
  * OML: fix possible segfault: add NULL check in oml_ipa_set_attr()
  * CTRL: make the CTRL-Interface IP address configurable
  * Remove obsolete define TLVP_PRES_LEN
  * DTX: fix SID-FIRST detection
  * scheduler: log lchan on which prim error occured
  * lc15,sysmobts l1_if: fix memleak in handle_mph_time_ind()
  * l1sap: Fix expired rach slot counting
  * l1sap: fix missing 'else's causing wrong rach frame expiry counts
  * deb: use gsm_data_shared.* from openbsc-dev
  * octphy: set tx attenuation via VTY
  * Revert "deb: use gsm_data_shared.* from openbsc-dev"
  * debian: Use the header files installed by openbsc-dev
  * build: Do not require more headers from OpenBSC
  * OML: internalize failure reporting
  * Add ctrl command to send OML alert
  * octphy VTY: fix vty write output for octphy's phy section
  * cosmetic: Remove stray newlines in octphy_vty.c
  * sysmo,lc15: fix memory leak at each call placed
  * cosmetic: remove stray newline in octphy's l1_oml.c
  * DTX: fix "unexpected burst" error
  * rsl: Fix dropping of LAPDm UA message.
  * Fix AMR HR DTX FSM logic.
  * octphy: Improve OML ADM state handling
  * sysmobts: Add correct nominal transmit power for sysmoBTS 1020
  * sysmobts_eeprom.h: Fix/extend model number definitions
  * Fix SACCH channel release indication not sent to BSC after location update.
  * Revert "sysmobts: Add correct nominal transmit power for sysmoBTS 1020"
  * tx_power: various cosmetic fixes in comments
  * tx_power: Change PA calibration tables to use delta vales
  * Add new unit-test for transmit power computation code
  * fix missing ~ in bit logic for lchan->si.valid in rsl_rx_sacch_inf_mod()
  * SACCH: fix sending of SI with an enum value > 7
  * SACCH SI: assert that SI enum vals fit in bit mask
  * all models: fix vty write: bts_model_config_write_phy
  * cosmetic: lchan_sacch_get: early-exit instead of nested-if
  * rsl: Output RTP stats before closing the socket.
  * osmo-trx-bts: Fix incorrect setting of RXGAIN and POWER parameters on second channel (TRX1) of osmo-trx
  * osmo-trx-bts: Fix osmo-bts-trx crash on startup during reading phy instance parameters from config file
  * Fix typo in TCH/H interleaving table
  * osmo-trx-bts: Fix incorrect bts shutdown procedure in case of abis connection closure
  * sysmobts: fully support trx_power_params
* Fri Jan  6 2017 mardnh@gmx.de
- Update to version 0.4.0.git1483701882.2cf6b73:
  * Move code to libosmocore
* Fri Jan  6 2017 mardnh@gmx.de
- Update to version 0.4.0.git1483698786.f376359:
  * DTX AMR HR: fix inhibition
  * fix: dyn ts: uplink measurement report
  * Add copyright for .deb packages
- run tests after the build
* Sun Dec 25 2016 mardnh@gmx.de
- Update to version 0.4.0.git1482415865.c2ecca6:
  * DTX: move scheduling check inside repeat_last_sid
  * DTX: further AMR SID cache fixes (lc15, sysmo)
  * DTX: move ONSET detection into separate function
  * DTX: send AMR voice alongside with ONSET
  * build: be robust against install-sh files above the root dir
  * configure: check for pkg-config presence
  * octphy: reintroducing multi-trx support
  * octopy: fixing renamed constant
  * DTX: fix 1st RTP packet drop
  * DTX: fix conversion from fn to ms
  * Move copy-pasted array into shared header
  * octphy: prevent mismatch between dsp-firmware and octphy headers
  * rsl: improving the log output
  * jenkins.sh: use osmo-build-dep.sh, log test failures
  * DTX DL: use FSM for AMR
  * TRX: fix building with latest DTX changes
  * DTX: fix array size calculation
  * msgb ctx: use new msgb_talloc_ctx_init() in various main()s
  * DTX AMR - fix buffer length check
  * Replace magic number with define
  * Fix lc15 build
  * jenkins-oct.sh: fix build: typo in deps path
  * Extend RTP RX callback parameters
  * DTX HR - fix array size calculation
  * Fix DTX DL AMR SIDscheduling logic
  * Add tools to check DTX operation
  * 11bit RACH support for osmo-bts-litecell15
  * DTX DL: split ONSET state handling
  * Remove obsolete define
  * DTX DL: add AMR HR support to scheduling check
  * DTX fix ONSET handling
  * Initialize parameters in osmo-trx for 11bit RACH
  * dtx_check.gawk: Fix false-positives in DTX check
  * Fix tests linking with libosmocodec
  * DTX DL: tighten check for enabled operation
  * DTX: wrap FSM signal dispatching
  * Add libosmocodec for octphy build
  * dtx_check.gawk: add check for repetitive SID FIRST
  * fix 'osmo-bts-* --version' segfault
  * Remove duplicated code
  * Replace link_id constant with define
  * l1sap: Fix use-after-free in loopback mode.
  * vty: Add commands to manually activate/deactivate a channel.
  * cosmetic: tweak README
  * vty: Ensure to not use negative (error) sapi value
  * octphy: multi-trx support: fix AC_CHECK order
  * osmo-bts-trx: remove obsolete include of netif/rtp.h
  * add jenkins_bts_trx.sh
  * add jenkins_oct_and_bts_trx.sh
  * jenkins: add jenkins_bts_model.sh
  * trx: Add "maxdlynb" VTY command to control max TA for Normal Bursts.
  * DTX DL AMR: rewrite FSM recursion
  * Remove duplicated code
  * cosmetic: vty prompts: add space after '#'
  * Fix AGCH/PCH proportional allocation
  * bursts test: test_pdtch: pre-init result mem
  * TRX: prevent segfault upon phy init
  * DTX: add explicit check if DTX enabled
  * Save RTP metadata in Control Buffer
  * osmo-bts-trx: fix lchan deactivation
  * DTX: fix TS adjustment for ONSET
  * Optionally use adaptive RTP jitter buffering
  * DTX: don't always perform AMR HR specific check
  * Fix some spelling errors
  * Integrate Debian packaging changes
* Sun Oct  2 2016 mardnh@gmx.de
- Update to version 0.4.0.git1475228189.94fa252:
  * doc: move dyn_pdch.msc to osmo-gsm-manuals.git
  * error log: rsl.c: typo x2
  * info log: l1sap.c: add '0x' to hex output
  * fix compiler warning: msg_utils.c: fn_chk() constify arg
  * cosmetic: pcu_sock.c: rename ts_is_pdch() to ts_should_be_pdch()
  * cosmetic: clarify TCH/F_PDCH related naming and comments
  * dyn PDCH: code dup: use conf_lchans_as_pchan()
  * prepare dyn TS: split/replace conf_lchans_for_pchan()
  * trx: Add EGPRS tables, sequences, and mappings
  * code dup: join [rsl_]lchan_lookup() from libbsc and osmo-bts
  * dyn TS: common TCH/F_TCH/H_PDCH implementation
  * sysmo/oml.c: rename ts_connect() to ts_opstart()
  * dyn TS: implement SysmoBTS specifics
  * lc15/oml.c: rename ts_connect() to ts_opstart()
  * dyn TS: implement litecell15 specifics
  * comment typo: common/l1sap.c
  * log typo: trx_sched_set_pchan()
  * dyn TS: sysmo,lc15: chan_nr_by_sapi(): add missing assertion
  * trx: Add EGPRS coding and decoding procedures
  * trx: Enable EGPRS handling through burst lengths
  * Activate PTCCH UL
  * fix comment in common/l1sap.c, function name changed
  * pcu_sock: use osmo_sock_unix_init() from libosmocore
  * Fix dsp tracing at phy config
  * octphy: fix build
  * dyn TS, dyn PDCH: common/l1sap.c: properly notice PDCH
  * dyn PDCH: trx l1_if.c: factor out trx_set_ts_as_pchan() from trx_set_ts()
  * dyn PDCH: complete for trx: implement bts_model_ts_[dis]connect()
  * dyn PDCH: trx l1_if.c: drop fixme, add comment
  * trx: Fix coverity BER calculation NULL dereference
  * Add .mailmap for mapping mail addresses in shortlog
  * ci/spatch: Remove the "static" analysis handling
  * Fill measurements data for L1SAP
  * osmo-bts-trx: Fix PCS1900 operation
  * osmo-bts-trx: log decoder bit errors as DEBUG, not NOTICE
  * dyn TS: complete for TRX
  * dyn TS: measurement.c: replace fixme with comment
  * sysmo,lc15: ts_connect_as(): log error also for pchan_as == TCH/F_PDCH
  * sysmo: fix dyn TS: Revert "Activate PTCCH UL" [in sysmobts]
  * sysmo: ts_connect: log channel combination name instead of number
  * Change interface in osmo-bts for 11 bit RACH
  * log: l1sap: add 0x to hex output of chan_nr, 5 times
  * dyn TS: measurement: use correct nr of subslots, rm code dup
  * cosmetic: common ts_is_pdch()
  * dyn TS: sysmo,lc15: ph_data_req: fix PDCH mode detection
  * Fix ip.access style dyn PDCH, broken in 37af36e85eca546595081246aec010fa7f6fd0be
  * common/rsl: move decision whether to chan act ack/nack to common function
  * oct: Attempt to enable the Octphy for the osmo-bts-oct build
  * octphy: fix build: Revert "octphy: fix for multiple trx with more than 1 dsp"
  * octphy: fix build: Revert "octphy: add support for multiple trx ids"
  * octphy: fix build with OCTSDR-OPENBSC-02.07.00-B708: name changed
  * dyn TS: if PCU is not connected, allow operation as TCH
  * Update parameters in osmo-bts-sysmo for 11bit RACH
  * log: sysmo,lc15: tweak log about sapi_cmds queue
  * log causing rx event for lchan_lookup errors
  * heed VTY 'line vty'/'bind' command
  * DTX: fix last SID saving
  * DTX: fix SID repeat scheduling
  * DTX: fix SID logic
  * lc15, sysmo: Use SID_FIRST_P1 to initiate DTX
  * octphy: Fixing missing payload type in ph. chan. activation
  * octphy: Fixing band selection for ARFCN 0
  * sysmobts_mgr, lc15bts_mgr: fix tall context for telnet vty
  * DTX: check Marker bit to send ONSET to L1
  * DTX: remove misleading comment
  * LC15: Clarify msgb ownership / fix memory leaks
* Sun Jul 17 2016 mardnh@gmx.de
- Update to version 0.4.0.git1468702853.4355021:
  * Fix ocmo-bts-octphy interaction with OsmoPCU
  * pcuif: Do not bump the PCU_IF version
  * octphy: Use the event defaults as base
  * Fix copy-paste issue
  * Update configuration examples
  * misc: Attempt to fix make distcheck and dumping docs
  * octphy: Enable TCH/H mode and begin testing
  * Fix SI2ter scheduling
  * Add explicit check for SI2quater index and count
  * Ignore binary and backup files
  * Add utility to check proper scheduling of SI
  * octphy: add missing include to fix the build
  * Fix typo in error message
  * octphy: use octasic's routines for debug output
  * octphy: add support for multiple trx ids
  * octphy: add example configuration with 2 trx
  * octphy: fix for multiple trx with more than 1 dsp
  * LC15: ignore build byproducts
  * LC15: add stubs for phy link/instance defaults
  * LC15: properly initialize unmapped phy instances
  * debian: Create initial packaging for the osmo-bts-trx
  * misc: Ignore files generated by a debian packaging build
  * jenkins: Add the build script from jenkins here
  * jenkins: Add the build script from jenkins here
  * Ensure TRX invariant
  * octphy: Update outdated config param name in error message.
  * Use libosmocore function for uplink measurements
  * Fix debug output
  * Fix RTP timestamps in case of DTX
  * Add DTXd support for sysmoBTS and LC15
  * Use libosmocodec for AMR RTP
  * octphy: Use the app. info. defaults as base
  * Close TRX session before opening new one
  * Fix debug output
  * DTXd: store/repeat last SID
  * DTXd: store/repeat last SID
  * DTXu: mark beginning of speech burst in RTP
  * l1sap.h: fix wrong L1SAP_FN2PTCCHBLOCK calculation according to TS 45.002 Table 6
  * common/abis.c: fix 100%% CPU usage after disconnecting OML/RSL link (Bug #1703)
  * sysmobts: Add the barebox boot state reservation
  * sysmo: add L3 handle to l1prim messages
  * LC15: Bring back DSP trace argument
  * LC15: Hardware changes: - Change system devices path - Remove obsoleted sensors and add new sensors - Change TRX and sensors numbering to 0,1 instead of 1,2 (JFD)
  * LC15: TRX nominal TX power can be used from EEPROM or from BTS configuration
  * Fix OML activation
  * TRX: Add vty command to power on/off transceiver
  * pcu_sock: add pcu_connected() to query PCU availability
  * tests/stubs.c: remove unused stubs
  * fix typo in error message ('at lEast')
  * oml, Set Chan Attr: treat unknown PCHAN types as error
  * dyn PDCH: rsl rx dchan: also log ip.access message names
  * dyn PDCH: cosmetic: lchan_to_GsmL1_SubCh_t(): add case for TCH_F_PDCH
  * doc: add ladder diagram on dynamic PDCH, add msc-README
  * add missing DSUM entry to bts_log_info_cat
  * TRX: add configuration example
  * Add .gitreview
  * fix compiler warning: printf format for sizeof()
  * fix compiler warning: add missing case (PHY_LINK_CONNECTING)
  * fix two compiler warnings: add two opaque struct declarations
  * dyn PDCH: add bts_model_ts_connect() and _disconnect() stubs
  * dyn PDCH: conf_lchans_for_pchan(): handle TCH/F_PDCH
  * dyn PDCH: pcu_tx_info_ind(): handle TCH/F_PDCH in PDCH mode
  * dyn PDCH: chan_nr_by_sapi(): handle TCH/F_PDCH according to ts->flags
  * dyn PDCH: implement main dyn PDCH logic in common/
  * dyn PDCH: sysmo-bts/oml.c: add ts_connect_as(), absorbing ts_connect() guts
  * dyn PDCH: sysmo: handle TCH/F_PDCH init like TCH/F
  * dyn PDCH: complete for sysmo-bts: implement bts_model_ts_*()
  * error log: two minor clarifications
  * debug log: log lchan state transitions
  * debug log: log TS pchan type on connect
  * DTX: add support for AMR/HR
  * Move copy-pasted code into common part
  * Use libosmocodec functions for AMR
  * Use error values instead of number for RSL error
  * Clarify logging message
  * fix lc15 build: put src/common/libbts.a left of -losmogsm
  * lc15: add L3 handle to l1prim messages
  * dyn PDCH: lc15: chan_nr_by_sapi(): handle TCH/F_PDCH according to ts->flags
  * dyn PDCH: lc15: add ts_connect_as(), absorbing ts_connect() guts
  * dyn PDCH: lc15: handle TCH/F_PDCH init like TCH/F
  * dyn PDCH: lc15: complete for litecell15-bts: implement bts_model_ts_*()
  * dyn PDCH: safeguard: exit if nothing pending in dyn_pdch_ts_disconnected()
  * vty: install orphaned trx nominal power command
  * fix compiler warnings: include bts_model.h in phy_link.c
  * fix compiler warning: remove useless 'static' storage class for struct decl
  * fix compiler warning: remove unused variable 'i' in calib_verify()
  * Make get_lchan_by_chan_nr globally available
  * DTXu: move copy-pasted code to common part
  * Remove duplicated nibble shift code
  * TRX: add Uplink DTX support for FR/HR
  * sysmobts: screnrc/systemd-service: Use osmo-bts-sysmo instead of sysmobts
  * Mark array as static const
  * sysmobts: Fix eeprom padding before gpg key
  * cosmetic: osmo-bts-trx: add comment, fix comment typo
  * log: osmo-bts-trx: change access burst logs to DEBUG level
  * log: osmo-bts-trx: change PDTCH block logs to DEBUG level
  * osmo-bts-trx: init OML only once by sending AVSTATE_OK with OPSTATE_ENABLED
  * sysmobts: dump PRACH and PTCCH parameters
* Sat Feb 20 2016 mardnh@gmx.de
- Update to version 0.4.0.git1455563767.94bb376:
  + sysmobts: Clarify msgb ownership / fix memory leaks
  + fix large amount of compiler warnings in common and sysmobts code
  + l1sap: Whitespace fixes.
  + sysmobts: add missing break statement in l1if_handle_ind()
  + sysmobts-v2/eepromreader: Add userspace program to read EEPROM
  + sysmobts-calib: Warn about firmware and header mismatch
  + fix some format specifiers
  + print a NOTICE message if lchan not activ in get_active_lchan_by_chan_nr()
  + LAPDm: Use T200 settings from OML rather than libosmocore defaults
  + Add support for Octasic OCTSDR-2G GSM PHY
  + OCTPHY: Replace '-lortp' with the proper pkg-config/autofoo version
  + OCTPHY: Ensure we write the phy-netdev parameter
  + OCTPHY: Exit gracefully if config file specifies no phy-netdev
  + OCTPHY: Fix various memory leaks and add comments on msgb ownership
  + OCTPHY: Block PHY indications until it is confirmed open
  + OCTPHY: Print NOTICE message if we receive supervisory frame
  + OCTPHY: Implement command re-transmission after message loss
  + OCTPHY: Obtain information from PHY and expose it in VTY
  + TRX: remove obsolete get_mac() function
  + TRX: Add stub bts_model_change_power() function
  + sysmoBTS: port 'press Ctrl+C twice for immediate exit' from osmo-bts-trx
  + TRX: some comments dscribing the scheduler.[ch] API
  + TRX: mark scheduler data structures as 'const'
  + TRX: use const for dummy and fcch burst definitions
  + TRX: Reduce magic numbers, introduce GSM_HYPERFRAME for 2715648
  + move 'GSM_FR_BYTES' and related definitiions to common part
  + use existing #define for FR/EFR frame length (33/31)
  + TRX: make trx_chan_desc static, it is not used externally
  + TRX: schedule: remove dead code
  + TRX: scheduler: whitespace cleanup
  + TRX: replace some more 2715648 magic numbers with GSM_HYPERFRAME
  + TRX: Don't use magic numbers when we have #defines
  + TRX: Don't hard-code 23 bytes, use GSM_MACBLOCK_LEN
  + TRX: the L1SAP queue contains mac blocks, not bursts (cosmetic)
  + Fix T200 default values
  + Make T200 default initialization even more robust
  + OCTPHY: Don't have files in EXTRA_DIST that don't exist (anymore)
  + ABIS: Support for multiple RSL connections
  + common/support.c: Remove unused file
  + Add new bts_model_ctrl_cmds_install()
  + merge bts-specific main function into common/main.c:bts_main()
  + OCTPHY: fix 'make dist' (missing header files)
  + main: Return something from the method
  + Fix T200 default values
  + lapdm: Add DEBUGP statement about T200 values being set for lchan
  + OML: Ignore T200 settings by BSC for now
  + octphy: Look-up the right timeslot and then the logical chan
  + Revert "oml: temporary debug hack"
  + abis: Add a queue of OML messages
  + fix compile warnings
  + L1SAP: Ensure we don't process MPH-TIME.indication on TRX != C0
  + fix migration of check_for_ciph_cmd() from sysmobts to l1sap
  + TRX: factor out the scheduler from remaining code
  + TRX: split scheduler in generic part and backend part
  + TRX: call trx_loop_sacch_clock from TRX scheduler backend
  + TRX: scheduler: don't access l1h->config from scheduler
  + TRX: scheduler: Move trx_sched_clock() to scheduler_trx.c
  + TRX: scheduler: Remove dependency to trx_if.[ch]
  + TRX: Move scheduler to src/common
  + Introduce new phy_link and phy_instance abstraction
  + don't touch OML MO when PHY link is established
  + port sysmobts to phy_link/phy_instance abstraction
  + abis.c: Fix segfault on OML link loss
  + sysmobts: make clock calibration eeprom default (again?)
  + LC15: Add initial support for the NuRAN Wireless Litecell 1.5
  + LC15: Disable DSP trace flags by default
  + LC15: use talloc pool for msgb and ortp library
  + LC15: configure.ac: use --enable-litecell15 insteda of --enable-litecell15-bts
  + LC15: configure.ac: Allow specifying an alternate include-dir
  + LC15: port litecell 1.5 support to recent osmo-bts master
  + LC15: Add example configuration file for Litecell 1.5
  + LC15: cosmetic whitespace fixes
  + LC15: Fix printed msgq file names in error messages
  + LC15: fix compiler warning against more recent libosmovty
  + introduce + use new generic vty_get_phy_instance()
  + sysmobts/LC15: Fix startup-time DSP trace flage configuration
  + LC15: Remove unused clk_use_eeprom and clk_src fields
  + LC15/sysmobts: Don't try to refer to fl1h from PHY config
  + LC15: Remove clk_cal (another unused struct member)
  + LC15: Call l1if_reset() after l1if_open()
  + move auto-band configuration commands to common/vty.c
  + declare pcu_direct in pcu_if.h
  + make PCU socket and telnet port configurable
  + Use consistent naming of binaries accross BTS models
  + LC15: Fix 'make dist' (missing include files)
  + LC15: set nominal transmit power of 37dBm for all TRX
  + LC15: remove bogus check_for_ciph_cmd() copy
  + sysmobts_vty: Fix null-check for pinst
  + use unsigned int to compare wih ARRAY_SIZE
  + scheduler: Fix ARRAY_SIZE() in trx_sched_init()
* Sat Dec 26 2015 mardnh@gmx.de
- Update to version 0.4.0.git1449483816.e28a20a:
  + amr: Catch up with the amr_mode changes
  + amr: Catch-up for the non-RTP mode after amr rename
  + configure.ac: Only require libgps if building for sysmoBTS
  + configure.ac: Depend on libosmotrau 0.3.2 (ortp statistics)
  + configure.ac: Add subdir-objects to suppress warnings
  + configure.ac: Better description for --enable-sysmocom-bts and --enable-trx
  + Revert "configure.ac: Add subdir-objects to suppress warnings"
  + Don't blindly link against '-lortp' but use pkg-config for that
  + TRX: catch up with trhe amr_mode naming changes
  + tests/Makefile.am: Don't use sysmobts SUBDIRS twice
  + cope with 'struct gsm_bts' without a tsc member
  + sysmobts: fix ph_data_req() msgb handling + alignment
  + sysmobts: Dont recycle PHY primitive for L1SAP in PH-DATA.ind
  + common/rsl.c: The presence of a valied measurement result is DEBUG
  + l1sap: Ensure we only pass PHY primitives of active lchans
  + osmo-bts-sysmo: Disable DSP trace flags by default
  + use talloc pool for msgb and ortp library
  + sysmobts: support eeprom map version 2
  + sysmobts: Catch up with the API changes and specify the version
* Tue Sep 22 2015 mardnh@gmx.de
- Update to version 0.3.0.git1442932914.f1fb0fa:
  + update README to bring it more in sync with reality.
  + audio/rsl: Include the connection identifier in the DLCX ind
  + audio/rsl: Include statistics for one call
  + audio/rsl: Honor the speech mode and don't send anything
  + Add BCCH message to PH-/MPH-/TCH-SAP interface
  + l1sap: Split ph_data_req() into smaller parts
  + Add RACH message to PH-/MPH-/TCH-SAP interface
  + l1sap: Use L1SAP_IS_CHAN_RACH instead of magic number 0x88
  + l1sap: fix coding style
  + l1sap: fix missing include file and resulting compiler warning
  + l1sap: RACH: Detect hand-over even on TRX0
  + l1sap: correctly set chan_nr on PRIM_PH_RACH / INDICATION
  + l1sap: sysmobts: remove obsolete get_lapdm_chan_by_hl2()
  + Add PCH/AGCH message to PH-/MPH-/TCH-SAP interface
  + l1sap: Add a warning about assuming BS_AG_BLKS_RES=1
  + Add PDCH messages to PH-/MPH-/TCH-SAP interface
  + l1sap: additional comments explaining l1sap changes in l1_if.c
  + Add TIME (MPH_INFO) IND messages to PH-/MPH-/TCH-SAP interface
  + l1sap: Re-introduce more correct RACH slot counting
  + Relace bts_model_get_time() by get_time() at common part
  + Move chan act/rel/modify from bts_model to PH-/MPH-/TCH-SAP interface
  + l1sap: re-introduce a comment that was lost during l1sap merge
  + Add TCH messages to PH-/MPH-/TCH-SAP interface
  + l1sap: Use {data,empty}_req_from_l1sap() and avoid code duplication
  + l1sap: Avoid compiler warnings regarding uninitialized nmsg
  + Add SDCCH/SACCH/FACCH messages to PH-/MPH-/TCH-SAP interface
  + sysmobts/l1_if: Sacch/Sdcc/Facch are handled in l1sap/core
  + l1sap: Port code to new ciphering handling
  + Add MEAS (MPH_INFO) IND message to PH-/MPH-/TCH-SAP interface
  + sysmobts: Clean up transitions for lchan cipher state
  + Send primitives at PH-/MPH-/TCH-SAP interface via GSMTAP
  + Move gsmtap VTY commands from osmo-bts-sysmo to common part
  + Add gsmtap option to command line to main.c of osmo-bts-sysmo
  + Remove obsolete gsmtap handling from osmo-bts-sysmo part.
  + Move detection of handover frames from sysmo-bts code to common code
  + move MS power control handling from sysmobts to common part
  + fix: make sysmobts tests only when sysmobts is enabled
  + Fix: Retrieve ARFCN (from OML) for TRX other than C0
  + Fix: Process all TRX on GSM Time indication, not only C0
  + Fix: Call e1inp_vty_init() before reading config file
  + Change to new structure of multirate at gsm_data_shared.h
  + TRX: Introduce osmobts-trx, a layer 1 implementation for OpenBTS tranceivers
  + Add test code for testing GSM burst transcoding
  + TRX: On negative response of critical commands, shutdown BTS
  + ABIS: Introduce bts_model_abis_close to indicate ABIS link failure.
  + TRX: Power down tranceiver and reset scheduler, if abis link is lost
  + TRX: Completed transcoding of TCH with reordering Table 2 of TS 05.03
  + Add test routing to test transcoding of TCH FR / FACCH frames
  + Fix: Check right result on bursts_test
  + TRX: Fixes and improvements of scheduler
  + TRX: Use received TRX clocks to determine availablility of tranceiver
  + TRX: Fix, never send confirm for DEACT SACCH request (TS 05.08 4.6)
  + TRX: Minor fixes, especially handle TOA of RACH correctly
  + TRX: Fixed swapped stealing bits
  + TRX: Completed TCH/F full rate support
  + TRX: Allow transcoding of TCH FR with MSB first (RTP) or LSB first (E1)
  + TRX: Lost TCH frame detection of omitted bursts from tranceiver
  + TRX: PDTCH (GPRS) works now
  + TRX: Add test code for PDTCH transcoding
  + TRX: Detect missing received bursts and fill them with zero-sbits
  + TRX: By default, send 20 frames in advance to tranceiver
  + TRX: Cleanup of channel transcoding
  + TRX: Replaced GSM 06.10 ordering table by table in libosmocodec
  + TRX: Ciphering
  + TRX: Fix of SCH burst data
  + TRX: Fixes to TRX interface
  + TRX: Improved handling of clock indications.
  + TRX: Implementation of MS power and timing advance loops
  + TRX: Out of range primitives found in downlink queue are not an error
  + TRX: Use link timeout value from BSC via OML attribute.
  + TRX: Code cleanup, prepare for other codecs than GSM full rate
  + TRX: Add support for EFR transcoding
  + Get RSSI from received uplink data and send to PCU
  + TRX: Support for AMR full speech
  + TRX: Add AMR Payload handling
  + TRX: Support for TCH/H and GSM half rate transcoding
  + TRX: Support for AMR half speech
  + TRX: Reset ciphering state when closing channel
  + TRX: Add VTY options to enable and disable SETTSC and SETBSIC
  + Allow one or more TRX to configure via VTY
  + TRX: Fix: Cleanly free TRX instances during initialization in case of an error
  + TRX: Fixed typos tranceiver -> transceiver
  + TRX: Report measurements
  + TRX: Clear lchan state when resetting TRX
  + TRX: Handover access burst support
  + TRX: Use correct slot type for GSM_PHCAN_BCCH
  + TRX: Disable handover burst detection when closing channel during detection
  + TRX: Process real time scheduling option is now similar to sysmobts
  + Add test case for successful handover and unsuccessful handover
  + TRX: Set ciphering to an initial state when activating channel
  + TRX: If no cipher algorithm is given, or if it is a5/0, reset cipher state
  + TRX: No need to set mode and cipher for PDCH
  + TRX: Fixup ciphering state names after rebasing
  + TRX: Add bts_model_trx_close to TRX implementation
  + TRX: Close TRX (shutdown all active channels) on ABIS link failure
  + TRX: Do not send burst on IDLE channels at TRX != C0
  + trx: Add option to set transmit power reduction via OML (BSC)
  + TRX: Fixed chan_nr for SACCH/8(7) at scheduler
  + TRX: Changed logging of unserved primitives from LOGL_NOTICE to LOGL_INFO
  + Allow TRX 0..254 at VTY, even if less TRX are available
  + tests: make tests for sysmobts conditional
  + build: Use AM_CPPFLAGS in Makefile.am
  + TRX: fix some typos in comments
  + TRX: Add VTY option to allow setting RTS advance in frames
  + TRX: Free bust buffer memory to when changing lchan type
  + TRX: Activate LCHAN of CCCH when CCCH is configured on time slot
  + trx: Set lchan inactive, only if the dedicated channel is deactivated
  + TRX: Show which TRX does not respond or rejects a command
  + TRX: Check if Transceiver indicates an out of range clock
  + TRX: Remove extra TCH/HS puncturing value
  + trx: Implement BER calculations.
  + tests: Update bursts_test to accommodate BER calculations.
  + trx: More logging for voice frame decoding functions.
  + trx: Fix typo in a log message.
  + trx: Remove unused variables.
  + trx: Cleanup unused parts of loops.c
  + trx: Assume 100%% BER if total decoded bits is 0 in l1if_process_meas_res()
  + trx: Send POWERON/OFF commands to osmo-bts only for the first channel.
  + trx: fix potential use of uninitialized toa variable.
  + tests: Update busrsts_test build.
  + fixup tests after bts_model_adjst_ms_pwr
  + make osmo-bts-trx provide bts_model_adjst_ms_pwr()
  + TRX: Add missing call to abis_init()
* Tue Jul 14 2015 mardnh@gmx.de
- Update to version 0.3.0.git1436860556.a7c276b:
  + sysmo-bts: Use correct boundaries of L1 msg when forwarding to L1 proxy
  + Add header file of PH-/MPH-/TCH-SAP interface to common part of osmo-bts
  + write_queue: Check the result of osmo_wqueue_enqueue and free
  + meas: Do not send incomplete measurement reports
* Sun Feb 15 2015 mardnh@gmx.de
- Update to version 0.3.0.git1423171973.b631bd2:
  + cbch: Speculative change to not change CHAN ACK for CBCH
  + msg: Generalize the message structure test
  + sysmobts: Begin with calib control from the sysmobts manager
  + sysmobts: Copy more of l1if_rf_clock_info_reset into the CTRL code
  + sysmobts: Use the ctrl interface for calibration
  + sysmobts: The correction for GPS is in the reverse direction
  + sysmobts: Initial version to use libgps to determine FIX state
  + sysmobts: Start the calibration the first time the link is up
  + sysmobts: Create a calibration loop that will be run
  + sysmobts: Improve some log messages for calib control
  + misc: Fix up testcase after 5a03e129a633637d0a6b57b3b5aa6d6596b938fe
  + sysmobts: Check mgr->calib.bts_conn for NULL
  + power/sysmobts: Add a manual ms power level control
  + power: Make it possible to force a power level
* Tue Dec 30 2014 mardnh@gmx.de
- Update to version 0.3.0.git1419943502.8fc2630:
  + sysmobts: Include the serial number in the find response
  + Initial CBCH support
  + CBCH: Implement CBCH block segmentation and RSL_MT_SMS_BC_CMD
  + SMS-CB: Use GSM412_ #defines from libosmocore rather than our own
  + SMS-CB: use gsm412_block_type from libosmocore
  + SMS-CB: Use GSM412_SEQ_NULL_MSG rather than 0xf
  + SMS-CB: Clean up + centralize generation of NULL block
* Thu Dec 18 2014 mardnh@gmx.de
- Update to version 0.3.0.git1418757748.c265bef:
  + bts: Move BTS and children into the enabled state after opstart
  + sysmobts: Actions can be executed in all levels
  + sysmobts: Add an option to stop the systemd sysmobts.service
  + eeprom: Fix brown paper bag introduced a long while ago
  + sysmobts: Don't list non integer parameters in the help
  + sysmobts: Read the clock calibration from another place
  + sysmobts: Remove unused global variables
  + sysmobts: Add "normal" actions to execute
  + sysmobts: Comment out the varpoware options that are not implemented
  + sysmobts: Add slave on/off action for the sysmoBTS2050
* Fri Sep 12 2014 mardnh@gmx.de
- update to version 0.3.0+git.1409175947.9f22fcf
- specfile cleanup
* Tue Apr 15 2014 mardnh@gmx.de
- update to version 0.3.0+git.1390316846.72ba533
* Fri Aug 23 2013 mardnh@gmx.de
- initial package written from scratch
